==> invenio-2.0.0.tar.gz: invenio-2.0.0/invenio/legacy/bibconvert/registry.py <==
# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2013, 2014 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA

import os

from flask.ext.registry import PkgResourcesDirDiscoveryRegistry, \
    ModuleAutoDiscoveryRegistry, RegistryProxy
from invenio.utils.datastructures import LazyDict

converterext = RegistryProxy(
    'converterext', ModuleAutoDiscoveryRegistry, 'converterext'
)

kb = LazyDict(lambda: dict((os.path.basename(f), f)
              for f in RegistryProxy('converterext.kb',
                                     PkgResourcesDirDiscoveryRegistry,
                                     'kb', registry_namespace=converterext)))

templates = LazyDict(lambda: dict((os.path.basename(f), f)
                     for f in RegistryProxy('converterext.templates',
                                            PkgResourcesDirDiscoveryRegistry,
                                            'templates',
                                            registry_namespace=converterext)))

==> invenio-2.0.3.tar.gz: invenio-2.0.3/invenio/legacy/bibconvert/registry.py <==
# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2013, 2014, 2015 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA

import os

from flask_registry import PkgResourcesDirDiscoveryRegistry, \
    ModuleAutoDiscoveryRegistry, RegistryProxy
from invenio.utils.datastructures import LazyDict

converterext = RegistryProxy(
    'converterext', ModuleAutoDiscoveryRegistry, 'converterext'
)

kb = LazyDict(lambda: dict((os.path.basename(f), f)
              for f in RegistryProxy('converterext.kb',
                                     PkgResourcesDirDiscoveryRegistry,
                                     'kb', registry_namespace=converterext)))

templates = LazyDict(lambda: dict((os.path.basename(f), f)
                     for f in RegistryProxy('converterext.templates',
                                            PkgResourcesDirDiscoveryRegistry,
                                            'templates',
                                            registry_namespace=converterext)))
